# snow-pc


[![image](https://img.shields.io/pypi/v/snow-pc.svg)](https://pypi.python.org/pypi/snow-pc)
[![image](https://img.shields.io/conda/vn/conda-forge/snow-pc.svg)](https://anaconda.org/conda-forge/snow-pc)


**A python package for automated processing of point clouds to simplify elevation creation, co-registration and differencing to facilitate the production of snow depth and vegetation products.**


-   Free software: MIT license
-   Documentation: https://Surfix.github.io/snow-pc
    

## Features

-   TODO
